#
# spec file for package wok
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           wok
Version:        2.5.0
Release:        2.2
Summary:        Cherrypy framework for multi-purpose plug-ins
License:        Apache-2.0
Group:          System/Management
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Url:            https://github.com/kimchi-project/wok
Source:         https://github.com/kimchi-project/wok/archive/%{version}.tar.gz
Source1:        %{name}.rpmlintrc

Requires:       fontawesome-fonts
Requires:       gettext-tools
Requires:       httpd
Requires:       logrotate
Requires:       python-Cheetah
Requires:       python-CherryPy >= 3.2.0
Requires:       python-M2Crypto
Requires:       python-jsonschema >= 1.3.0
Requires:       python-ldap
Requires:       python-lxml
Requires:       python-pam
Requires:       python-psutil >= 0.6.0
Requires:       python-xml

BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  libxslt-tools
BuildRequires:  openssl
BuildRequires:  pkg-config
BuildRequires:  python-Cython
BuildRequires:  python-libxml2
BuildRequires:  python-lxml
BuildRequires:  python-requests
BuildRequires:  python-setuptools
BuildRequires:  python3-libsass

BuildArch:      noarch

%if 0%{?suse_version} == 1110
Requires:       python-ordereddict
%endif

%if 0%{?suse_version} >= 1210
%global with_systemd 1
BuildRequires:  systemd
BuildRequires:  systemd-devel
%{?systemd_requires}
%endif

%description
WoK, Webserver of Kimchi is a cherrypy framework for multi-purpose plug-ins

%package devel
Summary:        Files needed to build wok plugins
Group:          Development/Tools/Other

%description devel
WoK, Webserver of Kimchi is a cherrypy framework for multi-purpose plug-ins


%prep
%setup -n %{name}-%{version}

%build
chmod 644 ./ui/css/src/vendor/compass-mixins/lib/compass/functions/_display.scss
./autogen.sh --system
make

%install
cd %{_builddir}/%{name}-%{version}
make DESTDIR=%{buildroot} install
install -d %{buildroot}%{_datadir}/wok/plugins
install -d %{buildroot}%{_sysconfdir}/wok/plugins.d
install -d %{buildroot}%{_unitdir}/wokd.service.d
install -Dm 0644 contrib/wok.conf.apache %{buildroot}/%{_sysconfdir}/apache2/vhosts.d/wok.conf

install -d %{buildroot}/%{_datadir}/wok/css
cp -r ui/css/src/vendor %{buildroot}/%{_datadir}/wok/css/vendor
cp -r ui/css/src/modules %{buildroot}/%{_datadir}/wok/css/modules

# Install the service scripts
mkdir -p %{buildroot}%{_sbindir}
%if 0%{?with_systemd}
install -Dm 0644 contrib/wokd.service.systemd %{buildroot}%{_unitdir}/wokd.service
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rcwokd
rm -f %{buildroot}%{_initrddir}/wokd
%else
install -Dm 0755 contrib/wokd.sysvinit %{buildroot}%{_initrddir}/wokd
ln -sf %{_initrddir}/wokd %{buildroot}%{_sbindir}/rcwokd
rm -f %{buildroot}%{_unitdir}/wokd.service
%endif

%find_lang %{name}
%fdupes %{buildroot}/%{_datadir}
%fdupes %{buildroot}/%{python_sitelib}

%pre
%if %{?with_systemd}
%service_add_pre wokd.service
%endif

%post
if [ ! -e /etc/wok/dhparams.pem ]; then
    openssl dhparam -dsaparam -out /etc/wok/dhparams.pem 2048 >/dev/null 2>&1 || :
fi
if [ ! -e /etc/wok/wok-key.pem ] || [ ! -e /etc/wok/wok-cert.pem ]; then
    openssl req -x509 -newkey rsa:4096 -keyout /etc/wok/wok-key.pem -out /etc/wok/wok-cert.pem -days 365 -nodes -subj "/C=US/CN=wok/O=kimchi-project.org" >/dev/null 2>&1 || :
fi

%if %{?with_systemd}
%service_add_post wokd.service
%else
%fillup_and_insserv wokd
%endif
# Enable the required apache modules if apache is installed
if [ -x /usr/sbin/a2enmod ]; then
  a2enmod proxy
  a2enmod proxy_http
  a2enmod proxy_wstunnel
  a2enmod rewrite
fi

%preun
%if %{?with_systemd}
%service_del_preun wokd.service
%else
%stop_on_removal wokd
%endif
# Do not disable the required apache modules if apache is
# installed: they may be used by other websites

%postun
%if %{?with_systemd}
%service_del_postun wokd.service
%else
%restart_on_update wokd
%insserv_cleanup
%endif

%files -f %{name}.lang
%defattr(-,root,root)
%doc AUTHORS ChangeLog
%if 0%{?suse_version} > 1320 || 0%{?leap_version} >= 420200
%license COPYING COPYING.ASL2 COPYING.LGPL
%else
%doc COPYING COPYING.ASL2 COPYING.LGPL
%endif
%{_bindir}/wokd
%dir %{python_sitelib}/wok
%{python_sitelib}/wok/*.py*
%{python_sitelib}/wok/API.json
%dir %{python_sitelib}/wok/plugins
%{python_sitelib}/wok/plugins/__init__.py*
%{python_sitelib}/wok/control
%{python_sitelib}/wok/model
%{python_sitelib}/wok/xmlutils
%dir %{_datadir}/wok
%{_datadir}/wok/doc
%{_datadir}/wok/ui
%dir %{_prefix}/lib/firewalld
%dir %{_prefix}/lib/firewalld/services
%{_prefix}/lib/firewalld/services/wokd.xml
%dir %{_datadir}/wok/plugins
%dir %{_sysconfdir}/nginx/conf.d/
%dir %{_sysconfdir}/nginx/
%config %{_sysconfdir}/nginx/conf.d/wok.conf
%dir %{_sysconfdir}/apache2/vhosts.d
%dir %{_sysconfdir}/apache2/
%config %{_sysconfdir}/apache2/vhosts.d/wok.conf
%config %{_sysconfdir}/logrotate.d/wokd
%dir %{_sysconfdir}/wok
%config(noreplace) %{_sysconfdir}/wok/wok.conf
%dir %{_sysconfdir}/wok/plugins.d
%{_var}/lib/wok
%{_localstatedir}/log/wok
%{_mandir}/man8/wokd.8.gz
%if %{?with_systemd}
%{_unitdir}/wokd.service
%dir %{_unitdir}/wokd.service.d
%else
%{_initrddir}/wokd
%endif
%{_sbindir}/rcwokd

%files devel
%defattr(-,root,root)
%{_datadir}/wok/css

%changelog
* Thu Nov  2 2017 lfu@suse.com
- Update to 2.5.0
  + Allow Wok server discover others on same subnet (Check:
    README-federation.md for more details)
  + Remove OpenSans fonts need
  + Bug fixes
- Removed patches:
  + 0001-Add-apache-configuration.patch
* Thu Jun 15 2017 cbosdonnat@suse.com
- Fix apache config not to redirect to localhost:8001
- Improve summary
* Tue Mar 21 2017 cbosdonnat@suse.com
- Update to release 2.4.0
  + Plugins management
  + Block authentication request after too many failures
  + Asynchronous UI notification using Websockets
  + Bug fixes
- Allow to use either nginx or apache2 as proxy
  Add patch: 0001-Add-apache-configuration.patch
- We don't need to force libvirtd stop when stopping wokd:
  Drop patch fix_obs_builderror.patch
* Mon Feb 20 2017 boris@steki.net
- updated to latest release 2.3.1
- bugfix release
  + please look at Changelog file for more info
* Thu Oct 27 2016 boris@steki.net
- updated to latest release 2.3.0
- bugfix release
  + please look at Changelog file for more info
* Wed Sep 14 2016 boris@steki.net
- updated to latest release 2.2.0
- bugfix release
  + a lot of changes please look at ChangeLog file for more info
* Tue Dec 29 2015 cbosdonnat@suse.com
- Release 2.0.0
  - Split into wok + plugins (kimchi, ginger and gingerbase)
